@@ -4,22 +4,24 @@ use crate::book::{Book, Line, Loader};
 use crate::html_convertor::{html_content, HtmlContent};
 use crate::view::TraceInfo;
 
-pub(crate) struct HtmlLoader {}
+pub(crate) struct HtmlLoader {
+	extensions: Vec<&'static str>,
+}
 
 pub(crate) struct HtmlBook {
 	content: HtmlContent,
 }
 
 impl HtmlLoader {
-	pub(crate) fn support(filename: &str) -> bool {
-		let filename = filename.to_lowercase();
-		filename.ends_with(".html") || filename.ends_with(".htm")
+	pub(crate) fn new() -> Self {
+		let extensions = vec![".html", ".htm"];
+		HtmlLoader { extensions }
 	}
 }
 
 impl Loader for HtmlLoader {
-	fn support(&self, filename: &str) -> bool {
-		Self::support(filename)
+	fn extensions(&self) -> &Vec<&'static str> {
+		&self.extensions
 	}
 
 	fn load_buf(&self, _filename: &str, content: Vec<u8>, _chapter: usize) -> Result<Box<dyn Book>> {
